@@ -463,13 +463,12 @@ Request.prototype._pipeContinue = function (stream, options) {
         stream.emit('error', error);
       });
       res.pipe(unzipObject).pipe(stream, options);
+      // don't emit 'end' until unzipObject has completed writing all its data.
+      unzipObject.once('end', () => this.emit('end'));
     } else {
       res.pipe(stream, options);
+      res.once('end', () => this.emit('end'));
     }
-
-    res.once('end', () => {
-      this.emit('end');
-    });
   });
   return stream;
 };
@@ -551,12 +550,13 @@ Request.prototype._redirect = function (res) {
   _initHeaders(this);
 
   // redirect
+  this.res = res;
   this._endCalled = false;
   this.url = url;
   this.qs = {};
   this._query.length = 0;
   this.set(headers);
-  this.emit('redirect', res);
+  this._emitRedirect();
   this._redirectList.push(this.url);
   this.end(this._callback);
   return this;
@@ -855,8 +855,8 @@ Request.prototype.request = function () {
     if (hasOwn(this._header, 'cookie')) {
       // merge
       const temporaryJar = new CookieJar.CookieJar();
-      temporaryJar.setCookies(this._header.cookie.split(';'));
-      temporaryJar.setCookies(this.cookies.split(';'));
+      temporaryJar.setCookies(this._header.cookie.split('; '));
+      temporaryJar.setCookies(this.cookies.split('; '));
       req.setHeader(
         'Cookie',
         temporaryJar.getCookies(CookieJar.CookieAccessInfo.All).toValueString()
@@ -969,6 +969,18 @@ Request.prototype._emitResponse = function (body, files) {
   return response;
 };
 
+/**
+ * Emit `redirect` event, passing an instanceof `Response`.
+ *
+ * @api private
+ */
+
+Request.prototype._emitRedirect = function () {
+  const response = new Response(this);
+  response.redirects = this._redirectList;
+  this.emit('redirect', response);
+};
+
 Request.prototype.end = function (fn) {
   this.request();
   debug('%s %s', this.method, this.url);
@@ -1080,7 +1092,7 @@ Request.prototype._end = function () {
         parser = exports.parse.image; // It's actually a generic Buffer
         buffer = true;
       } else if (multipart) {
-        const form = formidable();
+        const form = formidable.formidable();
         parser = form.parse.bind(form);
         buffer = true;
       } else if (isBinary(mime)) {
@@ -1112,7 +1124,7 @@ Request.prototype._end = function () {
     let parserHandlesEnd = false;
     if (buffer) {
       // Protectiona against zip bombs and other nuisance
-      let responseBytesLeft = this._maxResponseSize || 200_000_000;
+      let responseBytesLeft = this._maxResponseSize || 200000000;
       res.on('data', (buf) => {
         responseBytesLeft -= buf.byteLength || buf.length > 0 ? buf.length : 0;
         if (responseBytesLeft < 0) {
@@ -1149,6 +1161,31 @@ Request.prototype._end = function () {
           }
 
           if (parserHandlesEnd) {
+            if (multipart) {
+              // formidable v3 always returns an array with the value in it
+              // so we need to flatten it
+              if (object) {
+                for (const key in object) {
+                  const value = object[key];
+                  if (Array.isArray(value) && value.length === 1) {
+                    object[key] = value[0];
+                  } else {
+                    object[key] = value;
+                  }
+                }
+              }
+
+              if (files) {
+                for (const key in files) {
+                  const value = files[key];
+                  if (Array.isArray(value) && value.length === 1) {
+                    files[key] = value[0];
+                  } else {
+                    files[key] = value;
+                  }
+                }
+              }
+            }
             this.emit('end');
             this.callback(null, this._emitResponse(object, files));
           }
