@@ -501,10 +501,6 @@ RequestBase.prototype.abort = function () {
       throw new Error(
         'Superagent does not work in v13 properly with abort() due to Node.js core changes'
       );
-    } else if (semver.gte(process.version, 'v14.0.0')) {
-      // We have to manually set `destroyed` to `true` in order for this to work
-      // (see core internals of end-of-stream.js above in v14 branch as compared to v12)
-      this.req.destroyed = true;
     }
 
     this.req.abort(); // node
@@ -666,9 +662,13 @@ RequestBase.prototype.send = function (data) {
   // merge
   if (isObject_ && isObject(this._data)) {
     for (const key in data) {
+      if (typeof data[key] == 'bigint' && !data[key].toJSON)
+        throw new Error('Cannot serialize BigInt value to json');
       if (hasOwn(data, key)) this._data[key] = data[key];
     }
-  } else if (typeof data === 'string') {
+  }
+  else if (typeof data === 'bigint') throw new Error("Cannot send value of type BigInt");
+  else if (typeof data === 'string') {
     // default to x-www-form-urlencoded
     if (!type) this.type('form');
     type = this._header['content-type'];
