@@ -100,7 +100,7 @@ describe('request', function () {
 
       return Promise.all([request_, request_, request_]).then((results) => {
         for (const item of results) {
-          assert.equal(
+          assert.deepEqual(
             item.body,
             results[0].body,
             'It should keep returning the same result after being called once'
@@ -213,6 +213,31 @@ describe('request', function () {
             assert.fail();
           },
           (err) => {
+            assert.equal(200, err.status);
+            assert.equal(200, err.response.status);
+            assert.equal(err.message, 'boom');
+          }
+        );
+    });
+
+    it('with .ok() throwing an Error with status', () => {
+      if (typeof Promise === 'undefined') {
+        return;
+      }
+
+      return request
+        .get(`${uri}/echo`)
+        .ok(() => {
+          const err = new Error('boom');
+          err.status = 404;
+          throw err;
+        })
+        .then(
+          () => {
+            assert.fail();
+          },
+          (err) => {
+            assert.equal(404, err.status);
             assert.equal(200, err.response.status);
             assert.equal(err.message, 'boom');
           }
@@ -591,8 +616,8 @@ describe('request', function () {
       request_.end((error, res) => {
         try {
           assert(false, 'should not complete the request');
-        } catch (error_) {
-          done(error_);
+        } catch (err) {
+          done(err);
         }
       });
 
@@ -625,8 +650,8 @@ describe('request', function () {
       request_.end((error, res) => {
         try {
           assert(false, 'should not complete the request');
-        } catch (error_) {
-          done(error_);
+        } catch (err) {
+          done(err);
         }
       });
 
